==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/el/buddhist.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "τρέχον τρίμ.",
	"field-quarter-short-relative+1": "επόμ. τρίμ.",
	"field-tue-relative+-1": "προηγούμενη Τρίτη",
	"field-year": "έτος",
	"field-wed-relative+0": "αυτήν την Τετάρτη",
	"field-wed-relative+1": "επόμενη Τετάρτη",
	"timeFormat-short": "h:mm a",
	"field-minute": "λεπτό",
	"field-tue-narrow-relative+0": "αυτήν την Τρ",
	"field-tue-narrow-relative+1": "επόμ. Τρ",
	"field-thu-short-relative+0": "αυτήν την Πέμ.",
	"dateTimeFormat-short": "{1}, {0}",
	"field-thu-short-relative+1": "επόμ. Πέμ.",
	"field-day-relative+0": "σήμερα",
	"field-day-relative+1": "αύριο",
	"field-day-relative+2": "μεθαύριο",
	"field-wed-narrow-relative+-1": "προηγ. Τε",
	"field-year-narrow": "έτ.",
	"field-year-narrow-relative+0": "φέτος",
	"field-tue-relative+0": "αυτήν την Τρίτη",
	"field-year-narrow-relative+1": "επόμενο έτος",
	"field-tue-relative+1": "επόμενη Τρίτη",
	"field-second-short": "δευτ.",
	"dayPeriods-format-narrow-am": "πμ",
	"dateFormatItem-MMMd": "d MMM",
	"dayPeriods-format-abbr-am": "π.μ.",
	"field-week-relative+0": "αυτήν την εβδομάδα",
	"field-month-relative+0": "τρέχων μήνας",
	"field-week-relative+1": "επόμενη εβδομάδα",
	"field-month-relative+1": "επόμενος μήνας",
	"field-sun-narrow-relative+0": "αυτήν την Κυ",
	"timeFormat-medium": "h:mm:ss a",
	"field-mon-short-relative+0": "αυτήν τη Δευτ.",
	"field-sun-narrow-relative+1": "επόμ. Κυ",
	"field-mon-short-relative+1": "επόμ. Δευτ.",
	"field-second-relative+0": "τώρα",
	"months-standAlone-narrow": [
		"Ι",
		"Φ",
		"Μ",
		"Α",
		"Μ",
		"Ι",
		"Ι",
		"Α",
		"Σ",
		"Ο",
		"Ν",
		"Δ"
	],
	"dayPeriods-standAlone-abbr-pm": "μ.μ.",
	"field-month-short": "μήν.",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-yyyyMd": "d/M/y GGGGG",
	"field-day": "ημέρα",
	"field-year-relative+-1": "πέρσι",
	"dayPeriods-format-wide-am": "π.μ.",
	"field-sat-short-relative+-1": "προηγ. Σάβ.",
	"field-hour-relative+0": "αυτήν την ώρα",
	"dateFormatItem-yyyyMEd": "E, d/M/y GGGGG",
	"field-wed-relative+-1": "προηγούμενη Τετάρτη",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "προηγ. Σά",
	"field-second": "δευτερόλεπτο",
	"days-standAlone-narrow": [
		"Κ",
		"Δ",
		"Τ",
		"Τ",
		"Π",
		"Π",
		"Σ"
	],
	"dayPeriods-standAlone-wide-pm": "μ.μ.",
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-quarter": "τρίμηνο",
	"field-week-short": "εβδ.",
	"quarters-standAlone-wide": [
		"1ο τρίμηνο",
		"2ο τρίμηνο",
		"3ο τρίμηνο",
		"4ο τρίμηνο"
	],
	"days-format-narrow": [
		"Κ",
		"Δ",
		"Τ",
		"Τ",
		"Π",
		"Π",
		"Σ"
	],
	"field-tue-short-relative+0": "αυτήν την Τρ.",
	"field-tue-short-relative+1": "επόμ. Τρ.",
	"field-mon-relative+-1": "προηγούμενη Δευτέρα",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "μήνας",
	"field-day-narrow": "ημέρα",
	"field-minute-short": "λεπ.",
	"field-dayperiod": "π.μ./μ.μ.",
	"field-sat-short-relative+0": "αυτό το Σάβ.",
	"field-sat-short-relative+1": "επόμ. Σάβ.",
	"dayPeriods-format-narrow-pm": "μμ",
	"dateFormat-medium": "d MMM y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"eraAbbr": [
		"BE"
	],
	"quarters-standAlone-abbr": [
		"Τ1",
		"Τ2",
		"Τ3",
		"Τ4"
	],
	"dayPeriods-format-abbr-pm": "μ.μ.",
	"dateFormatItem-yyyyM": "M/y GGGGG",
	"field-second-narrow": "δ",
	"field-mon-relative+0": "αυτήν τη Δευτέρα",
	"field-mon-relative+1": "επόμενη Δευτέρα",
	"field-year-short": "έτ.",
	"months-format-narrow": [
		"Ι",
		"Φ",
		"Μ",
		"Α",
		"Μ",
		"Ι",
		"Ι",
		"Α",
		"Σ",
		"Ο",
		"Ν",
		"Δ"
	],
	"field-quarter-relative+-1": "προηγούμενο τρίμηνο",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"dayPeriods-standAlone-narrow-am": "π.μ.",
	"days-format-short": [
		"Κυ",
		"Δε",
		"Τρ",
		"Τε",
		"Πέ",
		"Πα",
		"Σά"
	],
	"dayPeriods-format-wide-pm": "μ.μ.",
	"field-sat-relative+-1": "προηγούμενο Σάββατο",
	"dateTimeFormat-long": "{1} - {0}",
	"dateFormatItem-Md": "d/M",
	"field-hour": "ώρα",
	"months-format-wide": [
		"Ιανουαρίου",
		"Φεβρουαρίου",
		"Μαρτίου",
		"Απριλίου",
		"Μαΐου",
		"Ιουνίου",
		"Ιουλίου",
		"Αυγούστου",
		"Σεπτεμβρίου",
		"Οκτωβρίου",
		"Νοεμβρίου",
		"Δεκεμβρίου"
	],
	"dateFormat-full": "EEEE, d MMMM y G",
	"field-month-relative+-1": "προηγούμενος μήνας",
	"field-quarter-short": "τρίμ.",
	"field-sat-narrow-relative+0": "αυτό το Σά",
	"field-fri-relative+0": "αυτήν την Παρασκευή",
	"field-sat-narrow-relative+1": "επόμ. Σά",
	"field-fri-relative+1": "επόμενη Παρασκευή",
	"field-sun-short-relative+0": "αυτήν την Κυρ.",
	"field-sun-short-relative+1": "επόμ. Κυρ.",
	"field-week-relative+-1": "προηγούμενη εβδομάδα",
	"field-quarter-short-relative+-1": "προηγ. τρίμ.",
	"months-format-abbr": [
		"Ιαν",
		"Φεβ",
		"Μαρ",
		"Απρ",
		"Μαΐ",
		"Ιουν",
		"Ιουλ",
		"Αυγ",
		"Σεπ",
		"Οκτ",
		"Νοε",
		"Δεκ"
	],
	"field-quarter-relative+0": "τρέχον τρίμηνο",
	"field-minute-relative+0": "αυτό το λεπτό",
	"timeFormat-long": "h:mm:ss a z",
	"field-quarter-relative+1": "επόμενο τρίμηνο",
	"field-wed-short-relative+-1": "προηγ. Τετ.",
	"dateFormat-short": "d/M/y GGGGG",
	"field-thu-short-relative+-1": "προηγ. Πέμ.",
	"field-year-narrow-relative+-1": "πέρσι",
	"days-standAlone-wide": [
		"Κυριακή",
		"Δευτέρα",
		"Τρίτη",
		"Τετάρτη",
		"Πέμπτη",
		"Παρασκευή",
		"Σάββατο"
	],
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"field-mon-narrow-relative+-1": "προηγ. Δε",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "προηγ. Πέ",
	"field-tue-narrow-relative+-1": "προηγ. Τρ",
	"dateFormatItem-yyyy": "y G",
	"dayPeriods-standAlone-narrow-pm": "μ.μ.",
	"field-wed-short-relative+0": "αυτήν την Τετ.",
	"months-standAlone-wide": [
		"Ιανουάριος",
		"Φεβρουάριος",
		"Μάρτιος",
		"Απρίλιος",
		"Μάιος",
		"Ιούνιος",
		"Ιούλιος",
		"Αύγουστος",
		"Σεπτέμβριος",
		"Οκτώβριος",
		"Νοέμβριος",
		"Δεκέμβριος"
	],
	"field-wed-short-relative+1": "επόμ. Τετ.",
	"field-sun-relative+-1": "προηγούμενη Κυριακή",
	"days-standAlone-abbr": [
		"Κυρ",
		"Δευ",
		"Τρί",
		"Τετ",
		"Πέμ",
		"Παρ",
		"Σάβ"
	],
	"dateTimeFormat-full": "{1} - {0}",
	"field-weekday": "καθημερινή",
	"field-quarter-narrow-relative+0": "τρέχον τρίμ.",
	"field-sat-relative+0": "αυτό το Σάββατο",
	"field-quarter-narrow-relative+1": "επόμ. τρίμ.",
	"field-sat-relative+1": "επόμενο Σάββατο",
	"months-standAlone-abbr": [
		"Ιαν",
		"Φεβ",
		"Μάρ",
		"Απρ",
		"Μάι",
		"Ιούν",
		"Ιούλ",
		"Αύγ",
		"Σεπ",
		"Οκτ",
		"Νοέ",
		"Δεκ"
	],
	"timeFormat-full": "h:mm:ss a zzzz",
	"dateFormatItem-MEd": "E, d/M",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "αυτήν την Πέ",
	"field-thu-narrow-relative+1": "επόμ. Πέ",
	"field-sun-narrow-relative+-1": "προηγ. Κυ",
	"field-mon-short-relative+-1": "προηγ. Δευτ.",
	"field-thu-relative+0": "αυτήν την Πέμπτη",
	"field-thu-relative+1": "επόμενη Πέμπτη",
	"field-fri-short-relative+-1": "προηγ. Παρ.",
	"field-thu-relative+-1": "προηγούμενη Πέμπτη",
	"field-week": "εβδομάδα",
	"quarters-format-wide": [
		"1ο τρίμηνο",
		"2ο τρίμηνο",
		"3ο τρίμηνο",
		"4ο τρίμηνο"
	],
	"dateFormatItem-Ed": "E d",
	"field-wed-narrow-relative+0": "αυτήν την Τε",
	"field-wed-narrow-relative+1": "επόμ. Τε",
	"field-quarter-narrow-relative+-1": "προηγ. τρίμ.",
	"field-year-short-relative+0": "φέτος",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-year-short-relative+1": "επόμενο έτος",
	"field-fri-short-relative+0": "αυτήν την Παρ.",
	"field-fri-short-relative+1": "επόμ. Παρ.",
	"days-standAlone-short": [
		"Κυ",
		"Δε",
		"Τρ",
		"Τε",
		"Πέ",
		"Πα",
		"Σά"
	],
	"field-hour-short": "ώρ.",
	"quarters-format-abbr": [
		"Τ1",
		"Τ2",
		"Τ3",
		"Τ4"
	],
	"field-month-narrow": "μήν.",
	"field-hour-narrow": "ώ",
	"field-fri-narrow-relative+-1": "προηγ. Πα",
	"field-year-relative+0": "φέτος",
	"field-year-relative+1": "επόμενο έτος",
	"field-fri-relative+-1": "προηγούμενη Παρασκευή",
	"field-tue-short-relative+-1": "προηγ. Τρ.",
	"field-minute-narrow": "λ",
	"days-format-wide": [
		"Κυριακή",
		"Δευτέρα",
		"Τρίτη",
		"Τετάρτη",
		"Πέμπτη",
		"Παρασκευή",
		"Σάββατο"
	],
	"field-mon-narrow-relative+0": "αυτήν τη Δε",
	"field-mon-narrow-relative+1": "επόμ. Δε",
	"field-year-short-relative+-1": "πέρσι",
	"field-zone": "ζώνη ώρας",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-quarter-narrow": "τρίμ.",
	"field-sun-short-relative+-1": "προηγ. Κυρ.",
	"field-day-relative+-1": "χθες",
	"dayPeriods-standAlone-abbr-am": "π.μ.",
	"field-day-relative+-2": "προχθές",
	"days-format-abbr": [
		"Κυρ",
		"Δευ",
		"Τρί",
		"Τετ",
		"Πέμ",
		"Παρ",
		"Σάβ"
	],
	"field-sun-relative+0": "αυτήν την Κυριακή",
	"field-sun-relative+1": "επόμενη Κυριακή",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "ημέρα",
	"field-week-narrow": "εβδ.",
	"field-era": "περίοδος",
	"field-fri-narrow-relative+0": "αυτήν την Πα",
	"field-fri-narrow-relative+1": "επόμ. Πα",
	"dayPeriods-standAlone-wide-am": "π.μ."
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/el/buddhist.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "τρέχον τρίμ.",
	"field-quarter-short-relative+1": "επόμ. τρίμ.",
	"field-tue-relative+-1": "προηγούμενη Τρίτη",
	"field-year": "έτος",
	"field-wed-relative+0": "αυτήν την Τετάρτη",
	"field-wed-relative+1": "επόμενη Τετάρτη",
	"timeFormat-short": "h:mm a",
	"field-minute": "λεπτό",
	"field-month-narrow-relative+-1": "προηγ. μήνας",
	"field-tue-narrow-relative+0": "αυτήν την Τρ",
	"field-tue-narrow-relative+1": "επόμ. Τρ",
	"field-thu-short-relative+0": "αυτήν την Πέμ.",
	"field-day-short-relative+-1": "χθες",
	"dateTimeFormat-short": "{1}, {0}",
	"field-thu-short-relative+1": "επόμ. Πέμ.",
	"field-day-relative+0": "σήμερα",
	"field-day-relative+1": "αύριο",
	"field-week-narrow-relative+0": "τρέχ. εβδ.",
	"field-day-relative+2": "μεθαύριο",
	"field-week-narrow-relative+1": "επόμ. εβδ.",
	"field-wed-narrow-relative+-1": "προηγ. Τε",
	"field-year-narrow": "έτ.",
	"field-era-short": "περ.",
	"field-year-narrow-relative+0": "φέτος",
	"field-tue-relative+0": "αυτήν την Τρίτη",
	"field-year-narrow-relative+1": "επόμενο έτος",
	"field-tue-relative+1": "επόμενη Τρίτη",
	"field-weekdayOfMonth": "καθημερινή μήνα",
	"field-second-short": "δευτ.",
	"dayPeriods-format-narrow-am": "πμ",
	"dateFormatItem-MMMd": "d MMM",
	"field-weekdayOfMonth-narrow": "καθημερ. μήνα",
	"dayPeriods-format-abbr-am": "π.μ.",
	"field-week-relative+0": "τρέχουσα εβδομάδα",
	"field-month-relative+0": "τρέχων μήνας",
	"field-week-relative+1": "επόμενη εβδομάδα",
	"field-month-relative+1": "επόμενος μήνας",
	"field-sun-narrow-relative+0": "αυτήν την Κυ",
	"timeFormat-medium": "h:mm:ss a",
	"field-mon-short-relative+0": "αυτήν τη Δευτ.",
	"field-sun-narrow-relative+1": "επόμ. Κυ",
	"field-mon-short-relative+1": "επόμ. Δευτ.",
	"field-second-relative+0": "τώρα",
	"dateFormatItem-yyyyQQQ": "G y QQQ",
	"months-standAlone-narrow": [
		"Ι",
		"Φ",
		"Μ",
		"Α",
		"Μ",
		"Ι",
		"Ι",
		"Α",
		"Σ",
		"Ο",
		"Ν",
		"Δ"
	],
	"eraNames": [
		"Β.Ε."
	],
	"field-weekOfMonth": "εβδομάδα μήνα",
	"dayPeriods-standAlone-abbr-pm": "μ.μ.",
	"field-month-short": "μήν.",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-yyyyMd": "d/M/y GGGGG",
	"field-day": "ημέρα",
	"field-dayOfYear-short": "ημ. έτους",
	"field-year-relative+-1": "πέρσι",
	"dayPeriods-format-wide-am": "π.μ.",
	"field-sat-short-relative+-1": "προηγ. Σάβ.",
	"field-hour-relative+0": "τρέχουσα ώρα",
	"dateFormatItem-yyyyMEd": "E, d/M/y GGGGG",
	"field-wed-relative+-1": "προηγούμενη Τετάρτη",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "προηγ. Σά",
	"field-second": "δευτερόλεπτο",
	"days-standAlone-narrow": [
		"Κ",
		"Δ",
		"Τ",
		"Τ",
		"Π",
		"Π",
		"Σ"
	],
	"dayPeriods-standAlone-wide-pm": "μ.μ.",
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-quarter": "τρίμηνο",
	"field-week-short": "εβδ.",
	"field-day-narrow-relative+0": "σήμερα",
	"field-day-narrow-relative+1": "αύριο",
	"quarters-standAlone-wide": [
		"1ο τρίμηνο",
		"2ο τρίμηνο",
		"3ο τρίμηνο",
		"4ο τρίμηνο"
	],
	"days-format-narrow": [
		"Κ",
		"Δ",
		"Τ",
		"Τ",
		"Π",
		"Π",
		"Σ"
	],
	"field-tue-short-relative+0": "αυτήν την Τρ.",
	"field-tue-short-relative+1": "επόμ. Τρ.",
	"field-mon-relative+-1": "προηγούμενη Δευτέρα",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "μήνας",
	"field-day-narrow": "ημ.",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "λεπ.",
	"field-dayperiod": "π.μ./μ.μ.",
	"field-sat-short-relative+0": "αυτό το Σάβ.",
	"field-sat-short-relative+1": "επόμ. Σάβ.",
	"dayPeriods-format-narrow-pm": "μμ",
	"dateFormat-medium": "d MMM y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"eraAbbr": [
		"BE"
	],
	"quarters-standAlone-abbr": [
		"Τ1",
		"Τ2",
		"Τ3",
		"Τ4"
	],
	"dayPeriods-format-abbr-pm": "μ.μ.",
	"dateFormatItem-yyyyM": "M/y GGGGG",
	"field-second-narrow": "δ.",
	"field-mon-relative+0": "αυτήν τη Δευτέρα",
	"field-mon-relative+1": "επόμενη Δευτέρα",
	"field-day-narrow-relative+-1": "χθες",
	"field-year-short": "έτ.",
	"months-format-narrow": [
		"Ι",
		"Φ",
		"Μ",
		"Α",
		"Μ",
		"Ι",
		"Ι",
		"Α",
		"Σ",
		"Ο",
		"Ν",
		"Δ"
	],
	"field-quarter-relative+-1": "προηγούμενο τρίμηνο",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"field-dayperiod-narrow": "πμ/μμ",
	"dayPeriods-standAlone-narrow-am": "πμ",
	"field-week-narrow-relative+-1": "προηγ. εβδ.",
	"days-format-short": [
		"Κυ",
		"Δε",
		"Τρ",
		"Τε",
		"Πέ",
		"Πα",
		"Σά"
	],
	"dayPeriods-format-wide-pm": "μ.μ.",
	"field-dayOfYear": "ημέρα έτους",
	"field-sat-relative+-1": "προηγούμενο Σάββατο",
	"dateTimeFormat-long": "{1} - {0}",
	"dateFormatItem-Md": "d/M",
	"field-hour": "ώρα",
	"months-format-wide": [
		"Ιανουαρίου",
		"Φεβρουαρίου",
		"Μαρτίου",
		"Απριλίου",
		"Μαΐου",
		"Ιουνίου",
		"Ιουλίου",
		"Αυγούστου",
		"Σεπτεμβρίου",
		"Οκτωβρίου",
		"Νοεμβρίου",
		"Δεκεμβρίου"
	],
	"dateFormat-full": "EEEE, d MMMM y G",
	"field-month-relative+-1": "προηγούμενος μήνας",
	"field-quarter-short": "τρίμ.",
	"field-sat-narrow-relative+0": "αυτό το Σά",
	"field-fri-relative+0": "αυτήν την Παρασκευή",
	"field-sat-narrow-relative+1": "επόμ. Σά",
	"field-fri-relative+1": "επόμενη Παρασκευή",
	"field-month-narrow-relative+0": "τρέχ. μήνας",
	"field-month-narrow-relative+1": "επόμ. μήνας",
	"field-sun-short-relative+0": "αυτήν την Κυρ.",
	"field-sun-short-relative+1": "επόμ. Κυρ.",
	"field-week-relative+-1": "προηγούμενη εβδομάδα",
	"field-quarter-short-relative+-1": "προηγ. τρίμ.",
	"months-format-abbr": [
		"Ιαν",
		"Φεβ",
		"Μαρ",
		"Απρ",
		"Μαΐ",
		"Ιουν",
		"Ιουλ",
		"Αυγ",
		"Σεπ",
		"Οκτ",
		"Νοε",
		"Δεκ"
	],
	"field-quarter-relative+0": "τρέχον τρίμηνο",
	"field-minute-relative+0": "τρέχον λεπτό",
	"timeFormat-long": "h:mm:ss a z",
	"field-quarter-relative+1": "επόμενο τρίμηνο",
	"field-wed-short-relative+-1": "προηγ. Τετ.",
	"dateFormat-short": "d/M/y GGGGG",
	"field-thu-short-relative+-1": "προηγ. Πέμ.",
	"field-year-narrow-relative+-1": "πέρσι",
	"days-standAlone-wide": [
		"Κυριακή",
		"Δευτέρα",
		"Τρίτη",
		"Τετάρτη",
		"Πέμπτη",
		"Παρασκευή",
		"Σάββατο"
	],
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"field-mon-narrow-relative+-1": "προηγ. Δε",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "προηγ. Πέ",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "προηγ. Τρ",
	"field-weekOfMonth-short": "εβδ. μήνα",
	"dateFormatItem-yyyy": "y G",
	"dayPeriods-standAlone-narrow-pm": "μμ",
	"field-wed-short-relative+0": "αυτήν την Τετ.",
	"dateFormatItem-M": "L",
	"months-standAlone-wide": [
		"Ιανουάριος",
		"Φεβρουάριος",
		"Μάρτιος",
		"Απρίλιος",
		"Μάιος",
		"Ιούνιος",
		"Ιούλιος",
		"Αύγουστος",
		"Σεπτέμβριος",
		"Οκτώβριος",
		"Νοέμβριος",
		"Δεκέμβριος"
	],
	"field-wed-short-relative+1": "επόμ. Τετ.",
	"field-sun-relative+-1": "προηγούμενη Κυριακή",
	"dateFormatItem-MMMMEd": "E, d MMMM",
	"days-standAlone-abbr": [
		"Κυρ",
		"Δευ",
		"Τρί",
		"Τετ",
		"Πέμ",
		"Παρ",
		"Σάβ"
	],
	"dateTimeFormat-full": "{1} - {0}",
	"dateFormatItem-d": "d",
	"field-weekday": "καθημερινή",
	"field-day-short-relative+0": "σήμερα",
	"field-quarter-narrow-relative+0": "τρέχον τρίμ.",
	"field-day-short-relative+1": "αύριο",
	"field-sat-relative+0": "αυτό το Σάββατο",
	"field-quarter-narrow-relative+1": "επόμ. τρίμ.",
	"field-sat-relative+1": "επόμενο Σάββατο",
	"field-week-short-relative+0": "τρέχ. εβδομάδα",
	"field-week-short-relative+1": "επόμ. εβδομάδα",
	"months-standAlone-abbr": [
		"Ιαν",
		"Φεβ",
		"Μάρ",
		"Απρ",
		"Μάι",
		"Ιούν",
		"Ιούλ",
		"Αύγ",
		"Σεπ",
		"Οκτ",
		"Νοέ",
		"Δεκ"
	],
	"field-dayOfYear-narrow": "ημ. έτους",
	"field-weekdayOfMonth-short": "καθημερ. μήνα",
	"timeFormat-full": "h:mm:ss a zzzz",
	"dateFormatItem-MEd": "E, d/M",
	"field-zone-narrow": "ζώνη",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "αυτήν την Πέ",
	"field-sun-narrow-relative+-1": "προηγ. Κυ",
	"field-mon-short-relative+-1": "προηγ. Δευτ.",
	"field-thu-narrow-relative+1": "επόμ. Πέ",
	"field-thu-relative+0": "αυτήν την Πέμπτη",
	"field-thu-relative+1": "επόμενη Πέμπτη",
	"field-fri-short-relative+-1": "προηγ. Παρ.",
	"field-thu-relative+-1": "προηγούμενη Πέμπτη",
	"field-week": "εβδομάδα",
	"quarters-format-wide": [
		"1ο τρίμηνο",
		"2ο τρίμηνο",
		"3ο τρίμηνο",
		"4ο τρίμηνο"
	],
	"dateFormatItem-Ed": "E d",
	"field-wed-narrow-relative+0": "αυτήν την Τε",
	"field-wed-narrow-relative+1": "επόμ. Τε",
	"field-quarter-narrow-relative+-1": "προηγ. τρίμ.",
	"field-year-short-relative+0": "φέτος",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-dayperiod-short": "πμ/μμ",
	"field-year-short-relative+1": "επόμενο έτος",
	"field-fri-short-relative+0": "αυτήν την Παρ.",
	"field-fri-short-relative+1": "επόμ. Παρ.",
	"days-standAlone-short": [
		"Κυ",
		"Δε",
		"Τρ",
		"Τε",
		"Πέ",
		"Πα",
		"Σά"
	],
	"field-week-short-relative+-1": "προηγ. εβδομάδα",
	"dateFormatItem-yyyyQQQQ": "G y QQQQ",
	"field-hour-short": "ώ.",
	"field-zone-short": "ζώνη",
	"quarters-format-abbr": [
		"Τ1",
		"Τ2",
		"Τ3",
		"Τ4"
	],
	"field-month-narrow": "μήν.",
	"field-hour-narrow": "ώ.",
	"field-fri-narrow-relative+-1": "προηγ. Πα",
	"field-year-relative+0": "φέτος",
	"field-year-relative+1": "επόμενο έτος",
	"field-era-narrow": "περ.",
	"field-fri-relative+-1": "προηγούμενη Παρασκευή",
	"eraNarrow": "BE",
	"field-tue-short-relative+-1": "προηγ. Τρ.",
	"field-minute-narrow": "λ.",
	"days-format-wide": [
		"Κυριακή",
		"Δευτέρα",
		"Τρίτη",
		"Τετάρτη",
		"Πέμπτη",
		"Παρασκευή",
		"Σάββατο"
	],
	"field-mon-narrow-relative+0": "αυτήν τη Δε",
	"field-mon-narrow-relative+1": "επόμ. Δε",
	"field-year-short-relative+-1": "πέρσι",
	"field-zone": "ζώνη ώρας",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-weekOfMonth-narrow": "εβδ. μήνα",
	"field-weekday-narrow": "καθημερ.",
	"field-quarter-narrow": "τρίμ.",
	"field-sun-short-relative+-1": "προηγ. Κυρ.",
	"field-day-relative+-1": "χθες",
	"dayPeriods-standAlone-abbr-am": "π.μ.",
	"field-day-relative+-2": "προχθές",
	"field-weekday-short": "καθημερ.",
	"days-format-abbr": [
		"Κυρ",
		"Δευ",
		"Τρί",
		"Τετ",
		"Πέμ",
		"Παρ",
		"Σάβ"
	],
	"field-sun-relative+0": "αυτήν την Κυριακή",
	"field-sun-relative+1": "επόμενη Κυριακή",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "ημ.",
	"field-week-narrow": "εβδ.",
	"field-era": "περίοδος",
	"field-fri-narrow-relative+0": "αυτήν την Πα",
	"field-fri-narrow-relative+1": "επόμ. Πα",
	"dayPeriods-standAlone-wide-am": "π.μ."
}
//end v1.x content
);
